Crate kcr_elasticsearch_k8s_elastic_co

Crate kcr_elasticsearch_k8s_elastic_co 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the elasticsearch.k8s.elastic.co group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

elasticsearch.k8s.elastic.co/v1

  • Elasticsearch

elasticsearch.k8s.elastic.co/v1alpha1

  • Elasticsearch

elasticsearch.k8s.elastic.co/v1beta1

  • Elasticsearch

Modules

v1
v1alpha1
v1beta1